@@ -1,10 +1,10 @@
 package HTML::Restrict::Types;
-our $VERSION = 'v2.4.0';
+our $VERSION = 'v2.4.1';
 use strict;
 use warnings;
 
 use Type::Library -base;
-use Type::Utils 1.000001 ();
+use Type::Utils ();
 
 BEGIN {
     Type::Utils::extends( 'Types::Common::Numeric', 'Types::Standard', );
@@ -30,7 +30,7 @@ HTML::Restrict::Types - Type library for HTML::Restrict
 
 =head1 VERSION
 
-version v2.4.0
+version v2.4.1
 
 =head1 AUTHOR
 
